@@ -16,6 +16,16 @@ static int window_height, window_width;
 static void ReadDirList(DirEntry *dir_entry);
 static void PrintDirEntry(WINDOW *win, int entry_no, int y, unsigned char hilight);
 static void BuildDirEntryList(DirEntry *dir_entry);
+static void HandleReadSubTree(DirEntry *dir_entry, DirEntry *start_dir_entry, BOOL *need_dsp_help);
+static void HandleUnreadSubTree(DirEntry *dir_entry, DirEntry *de_ptr, DirEntry *start_dir_entry, BOOL *need_dsp_help);
+static void MoveEnd(DirEntry **dir_entry);
+static void MoveHome(DirEntry **dir_entry);
+static void HandlePlus(DirEntry *dir_entry, DirEntry *de_ptr, char *new_login_path, DirEntry *start_dir_entry, BOOL *need_dsp_help);
+static void HandleTagDir(DirEntry *dir_entry, BOOL value);
+static void HandleTagAllDirs(DirEntry *dir_entry, BOOL value );
+static void HandleShowAllTagged(DirEntry *dir_entry,DirEntry *start_dir_entry, BOOL *need_dsp_help, int *ch);
+static void HandleShowAll(DirEntry *dir_entry, DirEntry *start_dir_entry, BOOL *need_dsp_help, int *ch);
+static void HandleSwitchWindow(DirEntry *dir_entry, DirEntry *start_dir_entry, BOOL *need_dsp_help, int *ch);
 
 static int dir_mode;
 
@@ -542,7 +552,7 @@ static void Moveppage(int *disp_begin_pos, int *cursor_pos, DirEntry **dir_entry
    return;
 }
 
-void MoveEnd(DirEntry **dir_entry)
+static void MoveEnd(DirEntry **dir_entry)
 {
     statistic.disp_begin_pos = MAXIMUM(0, total_dirs - window_height);
     statistic.cursor_pos     = total_dirs - statistic.disp_begin_pos - 1;
@@ -556,7 +566,7 @@ void MoveEnd(DirEntry **dir_entry)
     return;
 }
 
-void MoveHome(DirEntry **dir_entry)
+static void MoveHome(DirEntry **dir_entry)
 {
     if( statistic.disp_begin_pos == 0 && statistic.cursor_pos == 0 )
     {  /* Position 1 bereits errecht */
@@ -578,8 +588,8 @@ void MoveHome(DirEntry **dir_entry)
     return;
 }
 
-void HandlePlus(DirEntry *dir_entry, DirEntry *de_ptr, char *new_login_path,
-		DirEntry *start_dir_entry, BOOL *need_dsp_help)
+static void HandlePlus(DirEntry *dir_entry, DirEntry *de_ptr, char *new_login_path,
+		       DirEntry *start_dir_entry, BOOL *need_dsp_help)
 {
     if( !dir_entry->not_scanned ) {
         beep();
@@ -599,7 +609,7 @@ void HandlePlus(DirEntry *dir_entry, DirEntry *de_ptr, char *new_login_path,
     }
 }
 
-void HandleReadSubTree(DirEntry *dir_entry, DirEntry *start_dir_entry,
+static void HandleReadSubTree(DirEntry *dir_entry, DirEntry *start_dir_entry,
 		       BOOL *need_dsp_help)
 {
     ScanSubTree( dir_entry );
@@ -611,7 +621,7 @@ void HandleReadSubTree(DirEntry *dir_entry, DirEntry *start_dir_entry,
     *need_dsp_help = TRUE;
 }
 
-void HandleUnreadSubTree(DirEntry *dir_entry, DirEntry *de_ptr,
+static void HandleUnreadSubTree(DirEntry *dir_entry, DirEntry *de_ptr,
 			 DirEntry *start_dir_entry, BOOL *need_dsp_help)
 {
     if( dir_entry->not_scanned || (dir_entry->sub_tree == NULL) ) {
@@ -630,7 +640,7 @@ void HandleUnreadSubTree(DirEntry *dir_entry, DirEntry *de_ptr,
     return;
 }
 
-void HandleTagDir(DirEntry *dir_entry, BOOL value)
+static void HandleTagDir(DirEntry *dir_entry, BOOL value)
 {
     FileEntry *fe_ptr;
     for(fe_ptr=dir_entry->file; fe_ptr; fe_ptr=fe_ptr->next)
@@ -660,7 +670,7 @@ void HandleTagDir(DirEntry *dir_entry, BOOL value)
     return;
 }
 
-void HandleTagAllDirs(DirEntry *dir_entry, BOOL value )
+static void HandleTagAllDirs(DirEntry *dir_entry, BOOL value )
 {
     FileEntry *fe_ptr;
     long i;
@@ -695,7 +705,7 @@ void HandleTagAllDirs(DirEntry *dir_entry, BOOL value )
     return;
 }
 
-void HandleShowAllTagged(DirEntry *dir_entry,DirEntry *start_dir_entry, BOOL *need_dsp_help, int *ch)
+static void HandleShowAllTagged(DirEntry *dir_entry,DirEntry *start_dir_entry, BOOL *need_dsp_help, int *ch)
 {
     if( statistic.disk_tagged_files )
     {
@@ -734,7 +744,7 @@ void HandleShowAllTagged(DirEntry *dir_entry,DirEntry *start_dir_entry, BOOL *ne
     return;
 }
 
-void HandleShowAll(DirEntry *dir_entry, DirEntry *start_dir_entry, BOOL *need_dsp_help, int *ch)
+static void HandleShowAll(DirEntry *dir_entry, DirEntry *start_dir_entry, BOOL *need_dsp_help, int *ch)
 {
     if( statistic.disk_matching_files )
     {
@@ -773,7 +783,7 @@ void HandleShowAll(DirEntry *dir_entry, DirEntry *start_dir_entry, BOOL *need_ds
     return;
 }
 
-void HandleSwitchWindow(DirEntry *dir_entry, DirEntry *start_dir_entry, BOOL *need_dsp_help, int *ch)
+static void HandleSwitchWindow(DirEntry *dir_entry, DirEntry *start_dir_entry, BOOL *need_dsp_help, int *ch)
 {
     if( dir_entry->matching_files )
     {
@@ -1098,6 +1108,13 @@ int HandleDirWindow(DirEntry *start_dir_entry)
 		     need_dsp_help = TRUE;
 		     break;
 
+      case 'B':
+      case 'b':      /* About Box */
+                     AboutBox();
+                     need_dsp_help = TRUE;
+                     break;
+
+
       case 'Q' & 0x1F:
                      need_dsp_help = TRUE;
                      QuitTo(dir_entry);
