@@ -64,6 +64,7 @@ static void SilentTagWalkTaggedFiles( int (*fkt) (/* ??? */),
 			          );
 static void RereadWindowSize(DirEntry *dir_entry);
 static void ListJump( DirEntry * dir_entry, char *str );
+static char GetTypeOfFile(struct stat fst);
 
 
 
@@ -395,10 +396,17 @@ static int SortByAccTime(FileEntryList *e1, FileEntryList *e2)
 
 static int SortBySize(FileEntryList *e1, FileEntryList *e2)
 {
-  if (order)
-     return( e1->file->stat_struct.st_size - e2->file->stat_struct.st_size );
-  else
-     return( - (e1->file->stat_struct.st_size - e2->file->stat_struct.st_size) );
+  int result = 0;
+
+  if(e1->file->stat_struct.st_size < e2->file->stat_struct.st_size)
+    result = 1;
+  else if (e1->file->stat_struct.st_size > e2->file->stat_struct.st_size)
+    result = -1;
+
+  if(order)
+    result *= -1;
+
+  return result;
 }
 
 
@@ -530,7 +538,7 @@ static void ChangeFileEntry(void)
 }
 
 
-char GetTypeOfFile(struct stat fst)
+static char GetTypeOfFile(struct stat fst)
 {
 	if ( S_ISLNK(fst.st_mode) )
 		return '@';
