@@ -1,6 +1,4 @@
 /***************************************************************************
- *
- * $Header: /usr/local/cvsroot/utils/ytree/util.c,v 1.38 2019/09/29 10:37:49 werner Exp $
  *
  * Diverse Hilfsfunktionen
  *
@@ -919,7 +917,7 @@ int BuildUserFileEntry(FileEntry *fe_ptr,
   char access_time[13];
   char format1[60];
   char format2[60];
-  int  i, n;
+  int  n;
   char owner[OWNER_NAME_MAX + 1];
   char group[GROUP_NAME_MAX + 1];
   char *owner_name_ptr;
@@ -961,7 +959,7 @@ int BuildUserFileEntry(FileEntry *fe_ptr,
   sprintf(format1, "%%-%ds", max_filename_len);
   sprintf(format2, "%%-%ds", max_linkname_len);
 
-  for(sptr=template, dptr=buffer, i=0; *sptr; ) {
+  for(sptr=template, dptr=buffer; *sptr; ) {
 
     if(*sptr == '%') {
       sptr++;
