@@ -941,6 +941,7 @@ extern void SetMatchingParam(DirEntry *dir_entry);
 extern void Error(char *msg, char *module, int line);
 extern void Warning(char *msg);
 extern void Notice(char *msg);
+extern void AboutBox(void);
 extern void UnmapNoticeWindow(void);
 extern void SetFileMode(int new_file_mode);
 extern int  HandleFileWindow(DirEntry *dir_entry);
@@ -1094,8 +1095,9 @@ extern char *GetUserFileAction(int chkey, int *pchremap);
 extern char *GetUserDirAction(int chkey, int *pchremap);
 extern BOOL IsUserActionDefined(void);
 extern char *Getcwd(char *buffer, unsigned int len);
-extern int  RefreshDirWindow();
+extern int  RefreshDirWindow(void);
 extern char *StrLeft(const char *str, size_t count);
+extern char *StrRight(const char *str, size_t count);
 extern int  StrVisualLength(const char *str);
 extern int  WAttrAddStr(WINDOW *win, int attr, char *str);
 extern char *Strndup(const char *s, int len);
